tests.factories.input.definitions package — django_analyses 0.0.3 documentation

# tests.factories.input.definitions package

## Submodules

## tests.factories.input.definitions.boolean_input_definition module

class `tests.factories.input.definitions.boolean_input_definition.` `BooleanInputDefinitionFactory`

  Bases: `factory.django.DjangoModelFactory`

  `default` = <factory.faker.Faker object>
  `description` = <factory.faker.Faker object>
  `key` = <factory.faker.Faker object>
  `required` = <factory.faker.Faker object>

## tests.factories.input.definitions.directory_input_definition module

class `tests.factories.input.definitions.directory_input_definition.` `DirectoryInputDefinitionFactory`

  Bases: `factory.django.DjangoModelFactory`

  `description` = <factory.faker.Faker object>
  `key` = <factory.faker.Faker object>
  `required` = <factory.faker.Faker object>

## tests.factories.input.definitions.file_input_definition module

class `tests.factories.input.definitions.file_input_definition.` `FileInputDefinitionFactory`

  Bases: `factory.django.DjangoModelFactory`

  `description` = <factory.faker.Faker object>
  `key` = <factory.faker.Faker object>
  `required` = <factory.faker.Faker object>

## tests.factories.input.definitions.float_input_definition module

class `tests.factories.input.definitions.float_input_definition.` `FloatInputDefinitionFactory`

  Bases: `factory.django.DjangoModelFactory`

  `default` = <factory.faker.Faker object>
  `description` = <factory.faker.Faker object>
  `key` = <factory.faker.Faker object>
  `max_value` = <factory.faker.Faker object>
  `min_value` = <factory.faker.Faker object>
  `required` = <factory.faker.Faker object>

## tests.factories.input.definitions.input_definition module

class `tests.factories.input.definitions.input_definition.` `InputDefinitionFactory`

  Bases: `factory.django.DjangoModelFactory`

  `description` = <factory.faker.Faker object>
  `is_configuration` = <factory.faker.Faker object>
  `key` = <factory.faker.Faker object>
  `required` = <factory.faker.Faker object>

## tests.factories.input.definitions.integer_input_definition module

class `tests.factories.input.definitions.integer_input_definition.` `IntegerInputDefinitionFactory`

  Bases: `factory.django.DjangoModelFactory`

  `default` = <factory.faker.Faker object>
  `description` = <factory.faker.Faker object>
  `key` = <factory.faker.Faker object>
  `max_value` = <factory.faker.Faker object>
  `min_value` = <factory.faker.Faker object>
  `required` = <factory.faker.Faker object>

## tests.factories.input.definitions.list_input_definition module

class `tests.factories.input.definitions.list_input_definition.` `ListInputDefinitionFactory`

  Bases: `factory.django.DjangoModelFactory`

  `description` = <factory.faker.Faker object>
  `key` = <factory.faker.Faker object>
  `max_length` = <factory.faker.Faker object>
  `min_length` = <factory.faker.Faker object>
  `required` = <factory.faker.Faker object>

## tests.factories.input.definitions.string_input_definition module

class `tests.factories.input.definitions.string_input_definition.` `StringInputDefinitionFactory`

  Bases: `factory.django.DjangoModelFactory`

  `default` = <factory.faker.Faker object>
  `description` = <factory.faker.Faker object>
  `key` = <factory.faker.Faker object>
  `max_length` = <factory.faker.Faker object>
  `min_length` = <factory.faker.Faker object>
  `required` = <factory.faker.Faker object>

## Module contents